Documentation
¶
Overview ¶
Package mock_test is a generated GoMock package.
Package mock_test contains mock clients for testing
Package mock_test is a generated GoMock package.
Package mock_test is a generated GoMock package.
Index ¶
- type MockClient
- func (m *MockClient) Apply(ctx context.Context, obj runtime.ApplyConfiguration, ...) error
- func (m *MockClient) Create(ctx context.Context, obj client.Object, opts ...client.CreateOption) error
- func (m *MockClient) Delete(ctx context.Context, obj client.Object, opts ...client.DeleteOption) error
- func (m *MockClient) DeleteAllOf(ctx context.Context, obj client.Object, opts ...client.DeleteAllOfOption) error
- func (m *MockClient) EXPECT() *MockClientMockRecorder
- func (m *MockClient) Get(ctx context.Context, key client.ObjectKey, obj client.Object, ...) error
- func (m *MockClient) GroupVersionKindFor(obj runtime.Object) (schema.GroupVersionKind, error)
- func (m *MockClient) IsObjectNamespaced(obj runtime.Object) (bool, error)
- func (m *MockClient) List(ctx context.Context, list client.ObjectList, opts ...client.ListOption) error
- func (m *MockClient) Patch(ctx context.Context, obj client.Object, patch client.Patch, ...) error
- func (m *MockClient) RESTMapper() meta.RESTMapper
- func (m *MockClient) Scheme() *runtime.Scheme
- func (m *MockClient) Status() client.SubResourceWriter
- func (m *MockClient) SubResource(subResource string) client.SubResourceClient
- func (m *MockClient) Update(ctx context.Context, obj client.Object, opts ...client.UpdateOption) error
- type MockClientMockRecorder
- func (mr *MockClientMockRecorder) Apply(ctx, obj any, opts ...any) *gomock.Call
- func (mr *MockClientMockRecorder) Create(ctx, obj any, opts ...any) *gomock.Call
- func (mr *MockClientMockRecorder) Delete(ctx, obj any, opts ...any) *gomock.Call
- func (mr *MockClientMockRecorder) DeleteAllOf(ctx, obj any, opts ...any) *gomock.Call
- func (mr *MockClientMockRecorder) Get(ctx, key, obj any, opts ...any) *gomock.Call
- func (mr *MockClientMockRecorder) GroupVersionKindFor(obj any) *gomock.Call
- func (mr *MockClientMockRecorder) IsObjectNamespaced(obj any) *gomock.Call
- func (mr *MockClientMockRecorder) List(ctx, list any, opts ...any) *gomock.Call
- func (mr *MockClientMockRecorder) Patch(ctx, obj, patch any, opts ...any) *gomock.Call
- func (mr *MockClientMockRecorder) RESTMapper() *gomock.Call
- func (mr *MockClientMockRecorder) Scheme() *gomock.Call
- func (mr *MockClientMockRecorder) Status() *gomock.Call
- func (mr *MockClientMockRecorder) SubResource(subResource any) *gomock.Call
- func (mr *MockClientMockRecorder) Update(ctx, obj any, opts ...any) *gomock.Call
- type MockConfigReconciler
- type MockConfigReconcilerMockRecorder
- type MockIngressReconciler
- func (m *MockIngressReconciler) Delete(arg0 context.Context, arg1 types.NamespacedName) (bool, error)
- func (m *MockIngressReconciler) EXPECT() *MockIngressReconcilerMockRecorder
- func (m *MockIngressReconciler) Set(arg0 context.Context, arg1 []*model.IngressConfig) (bool, error)
- func (m *MockIngressReconciler) Upsert(arg0 context.Context, arg1 *model.IngressConfig) (bool, error)
- type MockIngressReconcilerMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockClient ¶
type MockClient struct {
// contains filtered or unexported fields
}
MockClient is a mock of Client interface.
func NewMockClient ¶
func NewMockClient(ctrl *gomock.Controller) *MockClient
NewMockClient creates a new mock instance.
func (*MockClient) Apply ¶ added in v0.31.0
func (m *MockClient) Apply(ctx context.Context, obj runtime.ApplyConfiguration, opts ...client.ApplyOption) error
Apply mocks base method.
func (*MockClient) Create ¶
func (m *MockClient) Create(ctx context.Context, obj client.Object, opts ...client.CreateOption) error
Create mocks base method.
func (*MockClient) Delete ¶
func (m *MockClient) Delete(ctx context.Context, obj client.Object, opts ...client.DeleteOption) error
Delete mocks base method.
func (*MockClient) DeleteAllOf ¶
func (m *MockClient) DeleteAllOf(ctx context.Context, obj client.Object, opts ...client.DeleteAllOfOption) error
DeleteAllOf mocks base method.
func (*MockClient) EXPECT ¶
func (m *MockClient) EXPECT() *MockClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockClient) Get ¶
func (m *MockClient) Get(ctx context.Context, key client.ObjectKey, obj client.Object, opts ...client.GetOption) error
Get mocks base method.
func (*MockClient) GroupVersionKindFor ¶ added in v0.26.0
func (m *MockClient) GroupVersionKindFor(obj runtime.Object) (schema.GroupVersionKind, error)
GroupVersionKindFor mocks base method.
func (*MockClient) IsObjectNamespaced ¶ added in v0.26.0
func (m *MockClient) IsObjectNamespaced(obj runtime.Object) (bool, error)
IsObjectNamespaced mocks base method.
func (*MockClient) List ¶
func (m *MockClient) List(ctx context.Context, list client.ObjectList, opts ...client.ListOption) error
List mocks base method.
func (*MockClient) Patch ¶
func (m *MockClient) Patch(ctx context.Context, obj client.Object, patch client.Patch, opts ...client.PatchOption) error
Patch mocks base method.
func (*MockClient) RESTMapper ¶
func (m *MockClient) RESTMapper() meta.RESTMapper
RESTMapper mocks base method.
func (*MockClient) Status ¶
func (m *MockClient) Status() client.SubResourceWriter
Status mocks base method.
func (*MockClient) SubResource ¶ added in v0.22.0
func (m *MockClient) SubResource(subResource string) client.SubResourceClient
SubResource mocks base method.
func (*MockClient) Update ¶
func (m *MockClient) Update(ctx context.Context, obj client.Object, opts ...client.UpdateOption) error
Update mocks base method.
type MockClientMockRecorder ¶
type MockClientMockRecorder struct {
// contains filtered or unexported fields
}
MockClientMockRecorder is the mock recorder for MockClient.
func (*MockClientMockRecorder) Apply ¶ added in v0.31.0
func (mr *MockClientMockRecorder) Apply(ctx, obj any, opts ...any) *gomock.Call
Apply indicates an expected call of Apply.
func (*MockClientMockRecorder) Create ¶
func (mr *MockClientMockRecorder) Create(ctx, obj any, opts ...any) *gomock.Call
Create indicates an expected call of Create.
func (*MockClientMockRecorder) Delete ¶
func (mr *MockClientMockRecorder) Delete(ctx, obj any, opts ...any) *gomock.Call
Delete indicates an expected call of Delete.
func (*MockClientMockRecorder) DeleteAllOf ¶
func (mr *MockClientMockRecorder) DeleteAllOf(ctx, obj any, opts ...any) *gomock.Call
DeleteAllOf indicates an expected call of DeleteAllOf.
func (*MockClientMockRecorder) Get ¶
func (mr *MockClientMockRecorder) Get(ctx, key, obj any, opts ...any) *gomock.Call
Get indicates an expected call of Get.
func (*MockClientMockRecorder) GroupVersionKindFor ¶ added in v0.26.0
func (mr *MockClientMockRecorder) GroupVersionKindFor(obj any) *gomock.Call
GroupVersionKindFor indicates an expected call of GroupVersionKindFor.
func (*MockClientMockRecorder) IsObjectNamespaced ¶ added in v0.26.0
func (mr *MockClientMockRecorder) IsObjectNamespaced(obj any) *gomock.Call
IsObjectNamespaced indicates an expected call of IsObjectNamespaced.
func (*MockClientMockRecorder) List ¶
func (mr *MockClientMockRecorder) List(ctx, list any, opts ...any) *gomock.Call
List indicates an expected call of List.
func (*MockClientMockRecorder) Patch ¶
func (mr *MockClientMockRecorder) Patch(ctx, obj, patch any, opts ...any) *gomock.Call
Patch indicates an expected call of Patch.
func (*MockClientMockRecorder) RESTMapper ¶
func (mr *MockClientMockRecorder) RESTMapper() *gomock.Call
RESTMapper indicates an expected call of RESTMapper.
func (*MockClientMockRecorder) Scheme ¶
func (mr *MockClientMockRecorder) Scheme() *gomock.Call
Scheme indicates an expected call of Scheme.
func (*MockClientMockRecorder) Status ¶
func (mr *MockClientMockRecorder) Status() *gomock.Call
Status indicates an expected call of Status.
func (*MockClientMockRecorder) SubResource ¶ added in v0.22.0
func (mr *MockClientMockRecorder) SubResource(subResource any) *gomock.Call
SubResource indicates an expected call of SubResource.
type MockConfigReconciler ¶
type MockConfigReconciler struct {
// contains filtered or unexported fields
}
MockConfigReconciler is a mock of ConfigReconciler interface.
func NewMockConfigReconciler ¶
func NewMockConfigReconciler(ctrl *gomock.Controller) *MockConfigReconciler
NewMockConfigReconciler creates a new mock instance.
func (*MockConfigReconciler) EXPECT ¶
func (m *MockConfigReconciler) EXPECT() *MockConfigReconcilerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockConfigReconcilerMockRecorder ¶
type MockConfigReconcilerMockRecorder struct {
// contains filtered or unexported fields
}
MockConfigReconcilerMockRecorder is the mock recorder for MockConfigReconciler.
type MockIngressReconciler ¶
type MockIngressReconciler struct {
// contains filtered or unexported fields
}
MockIngressReconciler is a mock of IngressReconciler interface.
func NewMockIngressReconciler ¶
func NewMockIngressReconciler(ctrl *gomock.Controller) *MockIngressReconciler
NewMockIngressReconciler creates a new mock instance.
func (*MockIngressReconciler) Delete ¶
func (m *MockIngressReconciler) Delete(arg0 context.Context, arg1 types.NamespacedName) (bool, error)
Delete mocks base method.
func (*MockIngressReconciler) EXPECT ¶
func (m *MockIngressReconciler) EXPECT() *MockIngressReconcilerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockIngressReconciler) Set ¶
func (m *MockIngressReconciler) Set(arg0 context.Context, arg1 []*model.IngressConfig) (bool, error)
Set mocks base method.
func (*MockIngressReconciler) Upsert ¶
func (m *MockIngressReconciler) Upsert(arg0 context.Context, arg1 *model.IngressConfig) (bool, error)
Upsert mocks base method.
type MockIngressReconcilerMockRecorder ¶
type MockIngressReconcilerMockRecorder struct {
// contains filtered or unexported fields
}
MockIngressReconcilerMockRecorder is the mock recorder for MockIngressReconciler.
func (*MockIngressReconcilerMockRecorder) Delete ¶
func (mr *MockIngressReconcilerMockRecorder) Delete(arg0, arg1 any) *gomock.Call
Delete indicates an expected call of Delete.